@@ -1,7 +1,6 @@
 import abc
 from typing import List
 
-from asgiref.sync import async_to_sync
 from django.apps import apps
 
 from django.core.management.base import BaseCommand
@@ -16,12 +15,14 @@ class BaseInitCommand(BaseCommand, abc.ABC):
         return f'{self.action} {self.name}'.title()
 
     @abc.abstractmethod
-    async def perform_init(self, app_config) -> List[str]:
+    def perform_init(self, app_config) -> List[str]:
         raise NotImplementedError()
 
     def handle(self, *args, **options):
         app_config = apps.get_app_config('django_cloud_tasks')
-        report = async_to_sync(self.perform_init)(app_config=app_config)
+        report = self.perform_init(
+            app_config=app_config,
+        )
 
         n = len(report)
         report_str = '\n'.join([f'- {name}' for name in report])
