@@ -7,8 +7,8 @@ class Command(BaseInitCommand):
     action = 'configure'
     name = 'tasks'
 
-    async def perform_init(self, app_config) -> List[str]:
+    def perform_init(self, app_config) -> List[str]:
         report = []
-        report.extend(await app_config.schedule_tasks())
-        report.extend(await app_config.initialize_subscribers())
+        report.extend(app_config.schedule_tasks())
+        report.extend(app_config.initialize_subscribers())
         return report
